@@ -176,7 +176,10 @@ def launch_behavex(args):
             )
 
         customized_json = get_param('customized_json')
-        if args.customized_json != '':
+        print(customized_json)
+        print(args.customized_json)
+
+        if args.customized_json == '':
             with open(customized_json, 'r') as f:
                 json_reports = json.load(f)
 
